@@ -47,7 +47,7 @@ public class CassandraClusterConnection {
 	/**
 	 * 
 	 * @param dropSchema set true if you want do drop the current and set up new one
-	 * @return the connection to cassandra cluster
+	 *  the connection to cassandra cluster
 	 */
 	protected CassandraClusterConnection(boolean dropSchema)	{
 		if (clusterName == null || host == null || keyspaceName == null) {
@@ -97,7 +97,7 @@ public class CassandraClusterConnection {
 	/**
 	 * 
 	 * @param dropSchema set true if you want do drop the current and set up new one
-	 * @return the connection to cassandra cluster
+	 * the connection to cassandra cluster
 	 */
 	protected CassandraClusterConnection(boolean dropSchema, String infrastructureName)	{
 		if (clusterName == null || host == null || keyspaceName == null) {
@@ -171,8 +171,8 @@ public class CassandraClusterConnection {
 
 	/**
 	 * 
-	 * @param cluster
-	 * @param dropIfExists
+	 * @param clusterContext
+	 * @param dropSchema
 	 * @throws ConnectionException
 	 */
 	public void SetUpKeySpaces(AstyanaxContext<Cluster> clusterContext, boolean dropSchema) {
@@ -254,7 +254,7 @@ public class CassandraClusterConnection {
 		/**
 		 * define Attachments CF with FeedId as secondary index
 		 */
-		ColumnFamilyDefinition cfDefAttachments = getStaticCFDef(DBCassandraAstyanaxImpl.ATTACHMENTS, "Feedid");
+		ColumnFamilyDefinition cfDefAttachments = getStaticCFDef(DBCassandraAstyanaxImpl.ATTACHMENTS, "feedId");
 
 
 		//get dynamic column families, act as auxiliary indexes
@@ -271,6 +271,7 @@ public class CassandraClusterConnection {
 		ColumnFamilyDefinition cfDefVREInvitesTimeline = getDynamicCFDef(DBCassandraAstyanaxImpl.VRE_INVITES);
 		ColumnFamilyDefinition cfDefHashtagsCounter = getDynamicCFDef(DBCassandraAstyanaxImpl.HASHTAGS_COUNTER);
 		ColumnFamilyDefinition cfDefHashtagTimeline = getDynamicCFDef(DBCassandraAstyanaxImpl.HASHTAGGED_FEEDS);
+		ColumnFamilyDefinition cfDefHashtagCommentsTimeline = getDynamicCFDef(DBCassandraAstyanaxImpl.HASHTAGGED_COMMENTS);
 
 
 		ksDef.setName(keyspaceName)
@@ -294,7 +295,8 @@ public class CassandraClusterConnection {
 		.addColumnFamily(cfDefEmailInvitesTimeline)
 		.addColumnFamily(cfDefVREInvitesTimeline)
 		.addColumnFamily(cfDefHashtagsCounter)
-		.addColumnFamily(cfDefHashtagTimeline);
+		.addColumnFamily(cfDefHashtagTimeline)
+		.addColumnFamily(cfDefHashtagCommentsTimeline);
 
 		cluster.addKeyspace(ksDef);	
 	}
