@@ -15,7 +15,9 @@ import org.gcube.portal.databook.shared.Like;
 import org.gcube.portal.databook.shared.Notification;
 import org.gcube.portal.databook.shared.NotificationChannelType;
 import org.gcube.portal.databook.shared.NotificationType;
+import org.gcube.portal.databook.shared.Post;
 import org.gcube.portal.databook.shared.RangeFeeds;
+import org.gcube.portal.databook.shared.RangePosts;
 import org.gcube.portal.databook.shared.ex.ColumnNameNotFoundException;
 import org.gcube.portal.databook.shared.ex.CommentIDNotFoundException;
 import org.gcube.portal.databook.shared.ex.FeedIDNotFoundException;
@@ -62,46 +64,91 @@ public interface DatabookStore {
 	 */
 	List<String> getPendingFriendRequests(String userid);
 	/**
+	 * @deprecated use saveUserPost
 	 * save a Feed instance in the store
 	 * @return true if everything went fine
 	 */
 	boolean saveUserFeed(Feed feed);
+	/**
+	 * save a Post instance in the store
+	 * @return true if everything went fine
+	 */
+	boolean saveUserPost(Post feed);
 	/**
 	 * Save a Feed instance in the store having more than one attachment
 	 * Use this if you need to attach more than one file to the post
 	 *
-	 * @param attachments, a list of attachments starting from the second
+	 * @deprecated use saveUserPost
+	 * @param attachments a list of attachments starting from the second
 	 * @return true if everything went fine
 	 */
 	boolean saveUserFeed(Feed feed, List<Attachment> attachments);
 	/**
-	 * delete a Feed from the store
+	 * Save a Post instance in the store having more than one attachment
+	 * Use this if you need to attach more than one file to the post
+	 *
+	 * @param attachments a list of attachments starting from the second
+	 * @return true if everything went fine
+	 */
+	boolean saveUserPost(Post post, List<Attachment> attachments);
+	/**
+	 * Delete a Feed from the store
+	 * @deprecated use saveUserPost
 	 * @throws FeedIDNotFoundException
 	 * @return true if everything went fine
 	 */
 	boolean deleteFeed(String feedid) throws FeedIDNotFoundException, PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException;
 	/**
-	 *  save a post in the VRES TimeLine in the store
+	 * delete a Feed from the store
+	 * @throws FeedIDNotFoundException
+	 * @return true if everything went fine
+	 */
+	boolean deletePost(String postid) throws FeedIDNotFoundException, PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException;
+	/**
+	 * Save a post in the VRES TimeLine in the store
+	 * @deprecated use savePostToVRETimeline
 	 * @param feedKey feedKey
 	 * @param vreid vre identifier
-	 * @return
 	 * @throws FeedIDNotFoundException
 	 */
 	boolean saveFeedToVRETimeline(String feedKey, String vreid) throws FeedIDNotFoundException;
 	/**
+	 *  save a post in the VRES TimeLine in the store
+	 * @param postKey the post id
+	 * @param vreid vre identifier
+	 * @throws FeedIDNotFoundException
+	 */
+	boolean savePostToVRETimeline(String postKey, String vreid) throws FeedIDNotFoundException;
+	/**
+	 * @deprecated use saveAppPost
 	 * save a Post instance in the store
 	 * @return true if everything went fine
 	 */
 	boolean saveAppFeed(Feed feed);	
 	/**
-	 * Save a feed instance in the store
+	 * save a Post instance in the store
+	 * @return true if everything went fine
+	 */
+	boolean saveAppPost(Post feed);	
+	/**
+	 * @deprecated use saveAppPost
+	 * Save a Post instance in the store
 	 * Use this if your app needs to attach more than one file to the post
 	 *
-	 * @param attachments, a list of attachments starting from the second
+	 * @param attachments a list of attachments starting from the second
 	 * @return true if everything went fine
 	 */
 	boolean saveAppFeed(Feed feed, List<Attachment> attachments);
 	/**
+	 * Save a Post instance in the store
+	 * Use this if your app needs to attach more than one file to the post
+	 *
+	 * @param attachments a list of attachments starting from the second
+	 * @return true if everything went fine
+	 */
+	boolean saveAppPost(Post feed, List<Attachment> attachments);
+	/**
+	 * @deprecated use readPost
 	 * read a feed from a given id 
 	 * @throws PrivacyLevelTypeNotFoundException 
 	 * @throws FeedTypeNotFoundException 
@@ -109,6 +156,14 @@ public interface DatabookStore {
 	 */	
 	Feed readFeed(String feedid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, FeedIDNotFoundException, ColumnNameNotFoundException;	
 	/**
+	 * read a feed from a given id 
+	 * @throws PrivacyLevelTypeNotFoundException 
+	 * @throws FeedTypeNotFoundException 
+	 * @throws ColumnNameNotFoundException 
+	 */	
+	Post readPost(String postid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, FeedIDNotFoundException, ColumnNameNotFoundException;	
+	/**
+	 * @deprecated use getAllPostsByUser instead
 	 * @param userid user identifier
 	 * return all the feeds belonging to the userid
 	 * @throws FeedTypeNotFoundException 
@@ -117,6 +172,15 @@ public interface DatabookStore {
 	 */
 	List<Feed> getAllFeedsByUser(String userid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, FeedIDNotFoundException, ColumnNameNotFoundException;
 	/**
+	 * @param userid user identifier
+	 * return all the feeds belonging to the userid
+	 * @throws FeedTypeNotFoundException 
+	 * @throws PrivacyLevelTypeNotFoundException 
+	 * @throws ColumnNameNotFoundException 
+	 */
+	List<Post> getAllPostsByUser(String userid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, FeedIDNotFoundException, ColumnNameNotFoundException;
+	/**
+	 * @deprecated use getAllPostsByApp instead 
 	 * @param appid application identifier
 	 * return all the feeds belonging to the appid
 	 * @throws FeedTypeNotFoundException 
@@ -125,6 +189,15 @@ public interface DatabookStore {
 	 */
 	List<Feed> getAllFeedsByApp(String appid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, FeedIDNotFoundException, ColumnNameNotFoundException;
 	/**
+	 * @param appid application identifier
+	 * return all the feeds belonging to the appid
+	 * @throws FeedTypeNotFoundException 
+	 * @throws PrivacyLevelTypeNotFoundException 
+	 * @throws ColumnNameNotFoundException 
+	 */
+	List<Post> getAllPostsByApp(String appid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, FeedIDNotFoundException, ColumnNameNotFoundException;
+	/**
+	 * @deprecated use getRecentCommentedPostsByUserAndDate instead
 	 * @param userid the user identifier like andrea.rossi
 	 * @param timeInMillis the initial time in millis to be considered
 	 * @return a list of feeds commented by userid starting from timeInMillis
@@ -132,15 +205,31 @@ public interface DatabookStore {
 	 */
 	List<Feed> getRecentCommentedFeedsByUserAndDate(String userid, long timeInMillis) throws Exception;
 	/**
+	 * @param userid the user identifier like andrea.rossi
+	 * @param timeInMillis the initial time in millis to be considered
+	 * @return a list of feeds commented by userid starting from timeInMillis
+	 * @throws Exception 
+	 */
+	List<Post> getRecentCommentedPostsByUserAndDate(String userid, long timeInMillis) throws Exception;
+	/**
+	 * @deprecated use getAllPortalPrivacyLevelPosts instead
 	 * return all the feeds whose Level is PORTAL
 	 * @throws PrivacyLevelTypeNotFoundException 
 	 * @throws ColumnNameNotFoundException 
 	 * @throws PrivacyLevelTypeNotFoundException 
 	 */
 	List<Feed> getAllPortalPrivacyLevelFeeds() throws FeedTypeNotFoundException, ColumnNameNotFoundException, PrivacyLevelTypeNotFoundException;
+	/**
+	 * return all the feeds whose Level is PORTAL
+	 * @throws PrivacyLevelTypeNotFoundException 
+	 * @throws ColumnNameNotFoundException 
+	 * @throws PrivacyLevelTypeNotFoundException 
+	 */
+	List<Post> getAllPortalPrivacyLevelPosts() throws FeedTypeNotFoundException, ColumnNameNotFoundException, PrivacyLevelTypeNotFoundException;
 
 	/**
 	 * return the most recent feeds for this user up to quantity param 
+	 * @deprecated
 	 * @param userid user identifier
 	 * @param  quantity the number of most recent feeds for this user
 	 * @return  a <class>List</class> of most recent feeds for this user
@@ -150,6 +239,17 @@ public interface DatabookStore {
 	 */
 	List<Feed> getRecentFeedsByUser(String userid, int quantity) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, FeedIDNotFoundException;
 	/**
+	 * return the most recent feeds for this user up to quantity param 
+	 * @param userid user identifier
+	 * @param  quantity the number of most recent feeds for this user
+	 * @return  a <class>List</class> of most recent feeds for this user
+	 * @throws FeedTypeNotFoundException 
+	 * @throws PrivacyLevelTypeNotFoundException 
+	 * @throws ColumnNameNotFoundException 
+	 */
+	List<Post> getRecentPostsByUser(String userid, int quantity) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, FeedIDNotFoundException;
+	/**
+	 * @deprecated use getAllPostsByVRE
 	 * @param vreid vre identifier
 	 * return all the feeds belonging to the userid
 	 * @throws FeedTypeNotFoundException 
@@ -157,8 +257,17 @@ public interface DatabookStore {
 	 * @throws ColumnNameNotFoundException 
 	 */
 	List<Feed> getAllFeedsByVRE(String vreid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, FeedIDNotFoundException;
+	/**
+	 * @param vreid vre identifier
+	 * return all the feeds belonging to the userid
+	 * @throws FeedTypeNotFoundException 
+	 * @throws PrivacyLevelTypeNotFoundException 
+	 * @throws ColumnNameNotFoundException 
+	 */
+	List<Post> getAllPostsByVRE(String vreid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, FeedIDNotFoundException;
 
 	/**
+	 * @deprecated use getRecentPostsByVRE
 	 * return the most recent feeds for this vre up to quantity param 
 	 * @param vreid VRES identifier
 	 * @param quantity the number of most recent feeds for this vre
@@ -169,7 +278,33 @@ public interface DatabookStore {
 	 */
 	List<Feed> getRecentFeedsByVRE(String vreid,  int quantity) throws IllegalArgumentException, PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, FeedIDNotFoundException;
 	/**
-	 * return the most recent feeds for this vre up to quantity param and the last index of the feeds in the timeline
+	 * return the most recent posts for this vre up to quantity param 
+	 * @param vreid VRES identifier
+	 * @param quantity the number of most recent posts for this vre
+	 * @return a <class>List</class> of most recent posts for this vre
+	 * @throws FeedTypeNotFoundException 
+	 * @throws PrivacyLevelTypeNotFoundException 
+	 * @throws ColumnNameNotFoundException 
+	 */
+	List<Post> getRecentPostsByVRE(String vreid,  int quantity) throws IllegalArgumentException, PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, FeedIDNotFoundException;
+
+	/**
+	 * return the most recent posts for this vre up to quantity param and the last index of the feeds in the timeline
+	 * lastReturnedFeedTimelineIndex is usuful to know from  where to start the range the second time you ask
+	 * because there are deletions
+	 * 
+	 * @deprecated use getRecentPostsByVREAndRange
+	 * @param vreid VRES identifier
+	 * @param from the range start (most recent feeds for this vre) has to be greater than 0
+	 * @param quantity the number of most recent feeds for this vre starting from "from" param
+	 * @return a <class>lastReturnedFeedTimelineIndex</class> containing of most recent feeds for this vre
+	 * @throws FeedTypeNotFoundException 
+	 * @throws PrivacyLevelTypeNotFoundException 
+	 * @throws ColumnNameNotFoundException 
+	 */
+	RangeFeeds getRecentFeedsByVREAndRange(String vreid,  int from, int quantity) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, FeedIDNotFoundException;
+	/**
+	 * return the most recent posts for this vre up to quantity param and the last index of the feeds in the timeline
 	 * lastReturnedFeedTimelineIndex is usuful to know from  where to start the range the second time you ask
 	 * because there are deletions
 	 * 
@@ -181,13 +316,21 @@ public interface DatabookStore {
 	 * @throws PrivacyLevelTypeNotFoundException 
 	 * @throws ColumnNameNotFoundException 
 	 */
-	RangeFeeds getRecentFeedsByVREAndRange(String vreid,  int from, int quantity) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, FeedIDNotFoundException;
+	RangePosts getRecentPostsByVREAndRange(String vreid,  int from, int quantity) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, FeedIDNotFoundException;
+
 	/**
+	 * @deprecated use getRecentPostsByUserAndDate
 	 * @param userid user identifier
 	 * @param timeInMillis time in milliseconds from which you want to start retrieve the feeds
 	 * @return the number of feeds in the range from: today to: timeInMillis
 	 */
 	List<Feed> getRecentFeedsByUserAndDate(String userid, long timeInMillis) throws IllegalArgumentException;
+	/**
+	 * @param userid user identifier
+	 * @param timeInMillis time in milliseconds from which you want to start retrieve the feeds
+	 * @return the number of feeds in the range from: today to: timeInMillis
+	 */
+	List<Post> getRecentPostsByUserAndDate(String userid, long timeInMillis) throws IllegalArgumentException;
 	/**
 	 * save a Notification instance in the store
 	 * @return true if everything went fine
@@ -272,7 +415,6 @@ public interface DatabookStore {
 	/**
 	 * set the notification preferences map (enable or disable the channels to be used for notifying the user)
 	 * @param userid  user identifier
-	 * @param notificationType the type of the notification
 	 * @param enabledChannels a map of the channels to which reach the user per notification, empty array or null values to set the key notification type off
 	 * @return true if everything was fine
 	 */
@@ -298,10 +440,16 @@ public interface DatabookStore {
 	 */
 	boolean addComment(Comment comment) throws FeedIDNotFoundException;
 	/**
+	 * @deprecated use getAllCommentByPost
 	 * @param feedid feed identifier
 	 * return all the comments belonging to the feedid
 	 */
 	List<Comment> getAllCommentByFeed(String feedid);
+	/**
+	 * @param postid the post identifier
+	 * return all the comments belonging to the postid
+	 */
+	List<Comment> getAllCommentByPost(String postid);
 	/**
 	 * @param userid user identifier
 	 * @param timeInMillis time in milliseconds from which you want to start retrieve the feeds
@@ -310,20 +458,20 @@ public interface DatabookStore {
 	List<Comment> getRecentCommentsByUserAndDate(String userid, long timeInMillis) throws Exception;
 	/**
 	 * edit a comment 
-	 * @param commentid the comment identifier to edit
+	 * @param comment the comment to edit
 	 * @return true if success, false otherwise
 	 */
 	boolean editComment(Comment comment) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, CommentIDNotFoundException, FeedIDNotFoundException;
 	/**
-	 * delete a comment 
+	 * deletes a comment 
 	 * @param commentid the comment identifier to delete
-	 * @parma feedid the feedid to which the comment is associated
+	 * @param feedid the feedid to which the comment is associated
 	 * @return true if success, false otherwise
 	 */
 	boolean deleteComment(String commentid, String feedid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, CommentIDNotFoundException, FeedIDNotFoundException;
 	/**
 	 * add a like to a feed
-	 * @param the like instance
+	 * @param like instance
 	 * @throws FeedIDNotFoundException 
 	 */
 	boolean like(Like like) throws FeedIDNotFoundException;
@@ -336,11 +484,18 @@ public interface DatabookStore {
 	 */
 	boolean unlike(String userid, String likeid, String feedid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, LikeIDNotFoundException, FeedIDNotFoundException;
 	/**
+	 * @deprecated use getAllLikedPostIdsByUser
 	 * @param userid user identifier
 	 * return all the feedids a user has liked
 	 */
 	List<String> getAllLikedFeedIdsByUser(String userid);
 	/**
+	 * @param userid user identifier
+	 * return all the feedids a user has liked
+	 */
+	List<String> getAllLikedPostIdsByUser(String userid);
+	/**
+	 * @deprecated use getAllLikedPostsByUser
 	 * @param userid user identifier
 	 * @param limit set 0 to get everything, an int to get the most recent -limit- liked feeds
 	 * @throws ColumnNameNotFoundException .
@@ -353,34 +508,77 @@ public interface DatabookStore {
 	List<Feed> getAllLikedFeedsByUser(String userid, int limit) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, FeedIDNotFoundException, ColumnNameNotFoundException;
 
 	/**
+	 * @param userid user identifier
+	 * @param limit set 0 to get everything, an int to get the most recent -limit- liked posts
+	 * @throws ColumnNameNotFoundException .
+	 * @throws FeedIDNotFoundException .
+	 * @throws FeedTypeNotFoundException . 
+	 * @throws PrivacyLevelTypeNotFoundException 
+	 * @throws FeedIDNotFoundException .
+	 * return all the feeds a user has liked
+	 */
+	List<Post> getAllLikedPostsByUser(String userid, int limit) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, FeedIDNotFoundException, ColumnNameNotFoundException;
+
+	/**
+	 * @deprecated use getRecentLikedPostsByUserAndDate
 	 * @param userid user identifier
 	 * @param timeInMillis time in milliseconds from which you want to start retrieve the feeds
 	 * @return the likes made to feeds in the range from: today to: timeInMillis
 	 */
 	List<Feed> getRecentLikedFeedsByUserAndDate(String userid, long timeInMillis) throws IllegalArgumentException;
 	/**
-	 * @param feedid feed identifier
-	 * return all the likes belonging to the feedid
+	 * @param userid user identifier
+	 * @param timeInMillis time in milliseconds from which you want to start retrieve the feeds
+	 * @return the likes made to feeds in the range from: today to: timeInMillis
 	 */
-	List<Like> getAllLikesByFeed(String feedid);
+	List<Post> getRecentLikedPostsByUserAndDate(String userid, long timeInMillis) throws IllegalArgumentException;
+	/**
+	 * @deprecated use getAllLikesByPost
+	 * @param postid postid identifier
+	 * return all the likes belonging to the postid
+	 */
+	List<Like> getAllLikesByFeed(String postid);
+	/**
+	 * @param postid postid identifier
+	 * return all the likes belonging to the postid
+	 */
+	List<Like> getAllLikesByPost(String postid);
 	/**
 	 * 
 	 * @param hashtags the hashtag including the '#'
-	 * @param feedid the feedid to which the hashtag is associated
+	 * @param postid the postid to which the hashtag is associated
 	 * @param vreid VRE identifier
 	 * @return true if success, false otherwise
 	 * @throws FeedIDNotFoundException
 	 */
-	boolean saveHashTags(String feedid, String vreid, List<String> hashtags) throws FeedIDNotFoundException;
+	boolean saveHashTags(String postid, String vreid, List<String> hashtags) throws FeedIDNotFoundException;
 	/**
 	 * 
 	 * @param hashtags the hashtag including the '#'
-	 * @param feedid the feedid to which the hashtag is associated
+	 * @param commentId the commentId to which the hashtag is associated
+	 * @param vreid VRE identifier
+	 * @return true if success, false otherwise
+	 * @throws CommentIDNotFoundException
+	 */
+	boolean saveHashTagsComment(String commentId, String vreid, List<String> hashtags) throws CommentIDNotFoundException;
+	/**
+	 * 
+	 * @param hashtags the hashtag including the '#'
+	 * @param postid the postid to which the hashtag is associated
 	 * @param vreid VRE identifier
 	 * @return true if success, false otherwise
 	 * @throws FeedIDNotFoundException
 	 */
-	boolean deleteHashTags(String feedid, String vreid, List<String> hashtags) throws FeedIDNotFoundException;
+	boolean deleteHashTags(String postid, String vreid, List<String> hashtags) throws FeedIDNotFoundException;
+	/**
+	 * 
+	 * @param hashtags the hashtag including the '#'
+	 * @param commentId the commentId to which the hashtag is associated
+	 * @param vreid VRE identifier
+	 * @return true if success, false otherwise
+	 * @throws CommentIDNotFoundException
+	 */
+	boolean deleteHashTagsComment(String commentId, String vreid, List<String> hashtags) throws CommentIDNotFoundException;
 	/**
 	 * get a map of vre hashtags where the key is the hashtag and the value is the occurrence of the hashtag in the VRE
 	 * @param vreid vre identifier (scope)
@@ -395,7 +593,7 @@ public interface DatabookStore {
 	 */
 	Map<String, Integer> getVREHashtagsWithOccurrenceFilteredByTime(String vreid, long timestamp);
 	/**
-	 * 
+	 * @deprecated use getVREPostsByHashtag
 	 * @param vreid VRE identifier
 	 * @param hashtag the hashtag to look for including the '#', it is case sensitive
 	 * @throws ColumnNameNotFoundException .
@@ -406,6 +604,19 @@ public interface DatabookStore {
 	 * @return all the feeds having the hashtag passed as parameter 
 	 */
 	List<Feed> getVREFeedsByHashtag(String vreid, String hashtag) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, FeedIDNotFoundException, ColumnNameNotFoundException;
+	/**
+	 * 
+	 * @param vreid VRE identifier
+	 * @param hashtag the hashtag to look for including the '#', it is case sensitive
+	 * @throws ColumnNameNotFoundException .
+	 * @throws FeedIDNotFoundException .
+	 * @throws FeedTypeNotFoundException . 
+	 * @throws PrivacyLevelTypeNotFoundException 
+	 * @throws FeedIDNotFoundException .
+	 * @return all the feeds having the hashtag passed as parameter 
+	 */
+	List<Post> getVREPostsByHashtag(String vreid, String hashtag) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, FeedIDNotFoundException, ColumnNameNotFoundException;
+
 	/**
 	 * Save the invite for a given email into a given vre
 	 * @param invite the invite object instanc to save
